# Makefile manages to ignore hardened_build
#global _hardened_build 1
%global groupname plugdev

# Use the optimized jansson-2.9 embedded with cgminer
%ifarch armv5tel
%global use_embedded 1
%else
%global use_embedded 0
%endif
# Use systemd
%global use_systemd 1

%if !%{use_embedded}
%global libjansson --with-system-jansson
%endif

%if %{use_systemd}
%global libsystemd --enable-libsystemd
%global _unitdir /usr/lib/systemd/system
%endif

Summary : A multi-threaded multi-pool miner for bitcoin and derivative coins
Name: cgminer
Version: 4.11.1
Release: 1%{dist}
License: GPLv3+
Group: Applications/Internet
Source0: http://ck.kolivas.org/apps/cgminer/cgminer-%{version}.tar.bz2
Patch0: cgminer.systemd.patch
URL: https://bitcointalk.org/index.php?topic=28402.0
BuildRoot: %{_tmppath}/%{name}-root
%if !%{use_embedded}
BuildRequires: jansson-devel
%endif
BuildRequires: libcurl-devel, libusb-devel, systemd-devel, gcc
BuildRequires: ncurses-devel

%description
This is a multi-threaded multi-pool GPU, FPGA and ASIC miner with ATI GPU
monitoring, (over)clocking and fanspeed support for bitcoin and derivative
coins. Do not use on multiple block chains at the same time!

This code is provided entirely free of charge by the programmer in his spare
time so donations would be greatly appreciated. Please consider donating to the
address below.

Con Kolivas <kernel@kolivas.org>
15qSxP1SQcUX3o4nhkfdbgyoWEFMomJ4rZ

%prep
%setup -q 
%if %{use_systemd}
%patch0 -p1 -b .systemd
%endif

%build

%ifarch armv5tel
%configure --disable-dependency-tracking --enable-icarus --enable-bitfury \
        --with-gnu-ld 
%else
# enable all drivers designed for generic USB hardware
%configure --disable-dependency-tracking \
	--with-gnu-ld %{?libjansson} %{?libsystemd} \
	--enable-avalon \
	--enable-avalon2 \
	--enable-avalon4 \
	--enable-avalon7 \
	--enable-bflsc \
	--enable-bitfury \
	--enable-cointerra \
	--enable-drillbit \
	--enable-hashfast \
	--enable-hashratio \
	--enable-icarus \
	--enable-klondike
%endif
make 	#LDFLAGS=-lm

%install
rm -rf %{buildroot}
#make_install
mkdir -p %{buildroot}%{_bindir}
install -p cgminer %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d
cp -p 01-cgminer.rules %{buildroot}%{_sysconfdir}/udev/rules.d
mkdir -p %{buildroot}/var/lib/cgminer
%if %{use_systemd}
mkdir -p %{buildroot}%{_unitdir}
install -pm 644 cgminer.service %{buildroot}%{_unitdir}
%endif

%files
%{!?_licensedir:%global license %%doc}
%license COPYING
%defattr (-,root,root)
%doc AUTHORS NEWS ChangeLog *README example.conf ABOUT*
%{_bindir}/cgminer
%{_sysconfdir}/udev/rules.d/01-cgminer.rules
%if %{use_systemd}
%{_unitdir}/*

%post
%systemd_post cgminer.service

%postun
%systemd_postun_with_restart cgminer.service

%preun
%systemd_preun cgminer.service

%endif

%pre
getent group  %{groupname} >/dev/null || groupadd -r %{groupname}
getent passwd cgminer > /dev/null || /usr/sbin/useradd -G %{groupname} \
        -c "Multi-pool bitcoin miner" \
        -r -d /var/lib/cgminer -s /sbin/nologin cgminer

%changelog

* Wed Jan  9 2019 Stuart Gathman <stuart@gathman.org> 4.11.1-1
- New upstream release

* Tue Sep  1 2015 Stuart Gathman <stuart@gathman.org> 4.9.2-1
- New release with ANTMiner 3 support.

* Wed Jan 29 2014 Stuart Gathman <stuart@gathman.org> 3.12.0-1
- New release with ANTMiner support.

* Tue Jan 28 2014 Stuart Gathman <stuart@gathman.org> 3.10.0-1
- update to 3.10.0

* Mon Dec 02 2013 Stuart Gathman <stuart@gathman.org> 3.8.4-1
- update to 3.8.4

* Sun Nov 17 2013 Stuart Gathman <stuart@gathman.org> 3.8.2-2
- Patch to fix zombie hotplug

* Sun Nov 17 2013 Stuart Gathman <stuart@gathman.org> 3.8.2-1
- update to 3.8.2

* Mon Sep 16 2013 Stuart Gathman <stuart@gathman.org> 3.4.3-1
- Initial RPM
